"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const bignumber_js_1 = __importDefault(require("bignumber.js"));
const web3_utils_1 = require("web3-utils");
const melonjs_1 = require("@melonproject/melonjs");
exports.address = accounting => accounting.contract.address;
exports.sharePrice = (accounting, _, context) => __awaiter(void 0, void 0, void 0, function* () {
    const calculations = yield context.loaders.accountingCalculations(accounting);
    return web3_utils_1.fromWei(calculations.sharePrice.toFixed());
});
exports.grossAssetValue = (accounting, _, context) => __awaiter(void 0, void 0, void 0, function* () {
    const calculations = yield context.loaders.accountingCalculations(accounting);
    return web3_utils_1.fromWei(calculations.gav.toFixed());
});
exports.netAssetValue = (accounting, _, context) => __awaiter(void 0, void 0, void 0, function* () {
    const calculations = yield context.loaders.accountingCalculations(accounting);
    return web3_utils_1.fromWei(calculations.nav.toFixed());
});
exports.holdings = (accounting, _, context) => __awaiter(void 0, void 0, void 0, function* () {
    const holdings = yield accounting.getFundHoldings(context.block);
    return Promise.all(holdings.map((holding) => __awaiter(void 0, void 0, void 0, function* () {
        const token = melonjs_1.findToken(context.environment.deployment, holding.address);
        let shareCostInAsset = new bignumber_js_1.default(0);
        if (token && token.symbol) {
            try {
                shareCostInAsset = yield accounting.getShareCostInAsset(new bignumber_js_1.default('1e18'), holding.address, context.block);
            }
            catch (e) { }
        }
        return { amount: holding.amount, token: token || null, shareCostInAsset };
    })));
});
